import osso

from youamp import context

class MaemoScrobbler:
    """submits song with wrong duration after 15s of playback"""
    def __init__(self):
        self._rpc = osso.Rpc(context)
        self._slot_free = True
        
    def send_start(self, song):
        print "scrobbler start"
        if not self._slot_free:
            self.send_stop()

        args = (song["artist"], song["title"], song["album"], 0, 30) # we dont know length and current pos
        self._rpc.rpc_run("com.nokia.songlistend", "/com/nokia/songlistend", "com.nokia.songlistend", "playing", args, wait_reply=False)
        self._slot_free = False

    def send_stop(self):
        print "scrobbler stop"
        self._rpc.rpc_run("com.nokia.songlistend", "/com/nokia/songlistend", "com.nokia.songlistend", "stopped", wait_reply=False)
        self._slot_free = True
